#!/bin/bash

MYPWD=$PWD
IBSIM_DESTDIR=$PWD/ibsim-routing

cd simulator-sources
make
if test $? -ne 0
then
	cd ..
	echo "Installation failed."
	exit 1
fi

cd ..
cp simulator-sources/orcs .

cd agraph_perl
make
if test $? -ne 0
then
	cd ..
	echo "Installation failed."
	exit 1
fi

cd ..

cd dot2osm
make
if test $? -ne 0
then
	cd ..
	echo "Installation failed."
	exit 1
fi
cd ..

mkdir $IBSIM_DESTDIR
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi
cd $IBSIM_DESTDIR
mkdir src
cd src
cp $MYPWD/ibsim-sources/ibsim-sources.tar.gz .

tar xzvf ibsim-sources.tar.gz

export LDFLAGS="-L$IBSIM_DESTDIR/lib/"
export CFLAGS="-I$IBSIM_DESTDIR/include/"
export CPPFLAGS="-I$IBSIM_DESTDIR/include/"

cd libibcommon
./autogen.sh
./configure --prefix=$IBSIM_DESTDIR
make
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

make install
cd ..

cd libibumad
./autogen.sh
./configure --prefix=$IBSIM_DESTDIR
make 
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

make install
cd ..

cd libibmad
./autogen.sh
./configure --prefix=$IBSIM_DESTDIR
make 
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

make install
cd ..

cd opensm
./autogen.sh
./configure --prefix=$IBSIM_DESTDIR
make
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

make install
cd ..

cd infiniband-diags
./autogen.sh
./configure --prefix=$IBSIM_DESTDIR
make
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

# EDIT THE MAKEFILE 
# SET PERL_INSTALLDIR=$IBDESTDIR/perllibs/
sed -i "s|PERL_INSTALLDIR =.*|PERL_INSTALLDIR = $IBSIM_DESTDIR/perllibs|" Makefile
make install
cd ..

export IB_DEV_DIR=$IBSIM_DESTDIR/src
export prefix=$IBSIM_DESTDIR

cd ibsim
sed -i "s|#define MAXNETNODES.*|#define MAXNETNODES    20480|" ibsim/sim.h
sed -i "s|#define MAXNETSWITCHS.*|#define MAXNETSWITCHS   2560|" ibsim/sim.h
make
if test $? -ne 0
then
	echo "Installation failed."
	exit 1
fi

make install
cd $MYPWD

write_start_ibsim() {
	echo "#!/bin/sh" > start_ibsim.sh
	echo "# This script starts the InfiniBand simulator and uses" >> start_ibsim.sh
	echo "# it to simulate the network you provided as first cmdline" >> start_ibsim.sh
	echo "# argument " >> start_ibsim.sh
	echo "" >> start_ibsim.sh
	echo "if test \$# -lt 1; then" >> start_ibsim.sh
	echo "	echo \"Please provide the an OpenSM topology file as argument\" 1>&2" >> start_ibsim.sh
	echo "	exit -1"  >> start_ibsim.sh
	echo "fi" >> start_ibsim.sh
	echo "export PATH=$IBSIM_DESTDIR/bin:$IBSIM_DESTDIR/sbin:\$PATH" >> start_ibsim.sh
	echo "export LD_PRELOAD=$IBSIM_DESTDIR/lib/umad2sim/libumad2sim.so" >> start_ibsim.sh
	echo "export LD_LIBRARY_PATH=$IBSIM_DESTDIR/lib:\$LD_LIBRARY_PATH" >> start_ibsim.sh
	echo "ibsim -s \$1" >> start_ibsim.sh
	chmod u+x start_ibsim.sh
}

write_start_opensm() {
	echo "#!/bin/sh" > start_osm.sh
	echo "# This script starts opensm after preloading the simulator library" >> start_osm.sh
	echo "# before you run this script you have to run ./start_ibsim and provide" >> start_osm.sh
	echo "# a topology file. You have to provide the name of the routing engine" >> start_osm.sh
	echo "# which opensm should use as a command line argument." >> start_osm.sh
	echo "# as soon as opensm prints the SUBNET UP message you may run dump_routes.sh" >> start_osm.sh
	echo "# to archive the routing tables for later analysis." >> start_osm.sh
	echo "" >> start_osm.sh
	echo "if test \$# -lt 1; then" >> start_osm.sh
	echo "  echo \"Please provide the name of a routing engine as argument\" 1>&2" >> start_osm.sh
	echo "  echo \"supported arguments: minhop, updn, file, ftree, lash, dor\" 1>&2" >> start_osm.sh
	echo "	exit -1"  >> start_osm.sh
	echo "fi" >> start_osm.sh
	echo "export PATH=$IBSIM_DESTDIR/bin:$IBSIM_DESTDIR/sbin:\$PATH" >> start_osm.sh
	echo "export LD_PRELOAD=$IBSIM_DESTDIR/lib/umad2sim/libumad2sim.so" >> start_osm.sh
	echo "export LD_LIBRARY_PATH=$IBSIM_DESTDIR/lib:\$LD_LIBRARY_PATH" >> start_osm.sh
	echo "" >> start_osm.sh
	echo "# Opensm tries to use /var for logs and cache files" >> start_osm.sh
	echo "# normaly users can't write to /var directly" >> start_osm.sh
	echo "export OSM_CACHE_DIR=/tmp" >> start_osm.sh
	echo "export OSM_TMP_DIR=/tmp" >> start_osm.sh
	echo "" >> start_osm.sh
	echo "# instead of going through \$PATH, some IB utils call \$IBPATH/foo" >> start_osm.sh
	echo "export IBPATH=$IBSIM_DESTDIR/sbin" >> start_osm.sh
	echo "" >> start_osm.sh
	echo "# start opensm, make it log to stdout" >> start_osm.sh
	echo "opensm -R \$1 -f -" >> start_osm.sh
	chmod u+x start_osm.sh
}

write_dump_routes() {
	echo "#!/bin/sh" > dump_routes.sh
	echo "# instead of going through \$PATH, some IB utils call \$IBPATH/foo" >> dump_routes.sh
	echo "export IBPATH=$IBSIM_DESTDIR/sbin" >> dump_routes.sh
	echo "export PATH=$IBSIM_DESTDIR/bin:$IBSIM_DESTDIR/sbin:\$PATH" >> dump_routes.sh
	echo "export LD_PRELOAD=$IBSIM_DESTDIR/lib/umad2sim/libumad2sim.so" >> dump_routes.sh
	echo "export LD_LIBRARY_PATH=$IBSIM_DESTDIR/lib:\$LD_LIBRARY_PATH" >> dump_routes.sh
	echo "" >> dump_routes.sh
	echo "dump_lfts.sh" >> dump_routes.sh
	chmod u+x dump_routes.sh
}


if test -e $IBSIM_DESTDIR/bin/ibsim; then 
	write_start_ibsim
	write_start_opensm
	write_dump_routes
	exit 0
else
	echo "Something went wrong during the install, check the output." 1>&2
	exit -1
fi


